[![Tests](https://github.com/DiddiZ/donk.ai/actions/workflows/python-package.yml/badge.svg)](https://github.com/DiddiZ/donk.ai/actions/workflows/python-package.yml)

# donk.ai

Reinforcement Learning Toolbox

## Features






# Todo
* Introduce State/Traj Distr Superclass
    * Allow to sample from
    * Add unit tests
* Automatic Sample/State Normalization
* GPS ALGO Class
* Refactor visualize trajectories
* Data logging
